#define pin_SW_SDA 18                                             // Назначение вывода Arduino для работы в качестве линии SDA для DS3231
#define pin_SW_SCL 19                                             // Назначение вывода Arduino для работы в качестве линии SCL для DS3231

#include <U8glib.h>                                               // Подключаем библиотеку U8glib
#include <Wire.h>                                                 // Библиотека iarduino_RTC будет использовать методы и функции библиотеки Wire.

#include <iarduino_RTC.h>                                         // Подключаем библиотеку iarduino_RTC для работы с модулями реального времени.
  iarduino_RTC time(RTC_DS3231);                                  // Объявляем объект time для работы с RTC модулем на базе чипа DS3231 по шине I2C

#include <iarduino_Pressure_BMP.h>                                // Подключаем библиотеку iarduino_Pressure_BMP для работы с датчиком BMP280
  iarduino_Pressure_BMP sensor (0x76);                            // Объявляем объект sensor для работы с датчиком BMP280, указываем его реальный адрес

U8GLIB_ST7920_128X64_1X u8g(10);                                  // Создаём объект u8g для работы с дисплеем, указывая номер вывода CS для шины SPI

unsigned long timing;
float TimeDisp[3];                                                // Объявляем массив для хранения значений давления

void setup(){
    delay(300);                                                   // Ждем готовности модуля отвечать на запросы
    time.begin();                                                 // Инициируем работу с модулем часов
    sensor.begin();                                               // Инициируем работу с датчиком. Текущая высота будет принята за 0 м
    timing = millis();                                            // Устанавливаем начальное згачение переменной timing
    TimeDisp[0] = 0;                                              // Забиваем массив начальными значениями
    TimeDisp[1] = 0;
    TimeDisp[2] = 0;
}

void loop (){
time.gettime();                                                   // Получаем значения времени
sensor.read(1);                                                   // Получаем данные датчика BMP280 c типом давления в мм.рт.ст.
Press();                                                          // Вызываем функцию формирования массива динамики значений давления

u8g.firstPage();                                                  // Вывод информации на дисплей в цикле: u8g.firstPage(); do{...команды...while(u8g.nextPage());

    do{  u8g.setColorIndex(1);                                    // Выбираем черный цвет
         u8g.drawBox(0, 0, 128, 11);                              // Выводим прямоугольник с координатами левого верхнего угла 0,0 и размерами 128x11
         u8g.setFont(u8g_font_6x10);                              // Выбираем шрифт u8g_font_6x10
         u8g.setColorIndex(0);                                    // Выбираем белый цвет (цвет фона)
         u8g.drawStr(33, 9, "RN1TU Clock");                       // Выводим текст "RN1TU Clock"  в позиции  33х9
         
         u8g.setColorIndex(1);                                    // Выбираем черный цвет
                 
         u8g.setFont(u8g_font_courB24n);                          // Выбираем шрифт u8g_font_courB24n
         
         u8g.setPrintPos(  3, 37); u8g.print(time.Hours/10);      // Выводим старший разряд часов    в позиции   3х37
         u8g.setPrintPos( 20, 37); u8g.print(time.Hours%10);      // Выводим младший разряд часов    в позиции  20х37
         u8g.drawStr    ( 33, 37, ":");                           // Выводим двоеточие               в позиции  33х37
         u8g.setPrintPos( 46, 37); u8g.print(time.minutes/10);    // Выводим старший разряд минут    в позиции  46х37
         u8g.setPrintPos( 63, 37); u8g.print(time.minutes%10);    // Выводим младший разряд минут    в позиции  63х37
         u8g.drawStr    ( 76, 37, ":");                           // Выводим двоеточие               в позиции  76х37
         u8g.setPrintPos( 89, 37); u8g.print(time.seconds/10);    // Выводим старший разряд секунд   в позиции  89х37
         u8g.setPrintPos(106, 37); u8g.print(time.seconds%10);    // Выводим младший разряд секунд   в позиции 106х37

         u8g.setFont(u8g_font_6x10);                              // Выбираем шрифт u8g_font_6x10
         
         u8g.setPrintPos( 29, 50); u8g.print(time.day);           // Выводим значение даты из модуля чаос реального времени  
         u8g.drawStr( 45, 50, "-");                               // Выводим текстовую строку "-"
         u8g.setPrintPos( 55, 50); u8g.print(time.month);         // Выводим значение месяца из модуля чаос реального времени
         u8g.drawStr( 70, 50, "-");                               // Выводим текстовую строку "-"
         u8g.drawStr( 80, 50, "20");                              // Выводим текстовую строку "20"
         u8g.setPrintPos( 92, 50); u8g.print(time.year);          // Выводим значение года из модуля чаос реального времени

         u8g.drawStr(27, 62, "mmHg");                             // Выводим текстовую строку "mmHg"
         u8g.setPrintPos( 5, 62); u8g.print(sensor.pressure,0);   // Выводим значение давления из модуля ВМР280 без знаков после запятой
         u8g.drawStr(116, 62, "C");                               // Выводим текстовую строку "C"
         u8g.setPrintPos( 87, 62); u8g.print(sensor.temperature,1); // Выводим значение температуры из модуля ВМР280 с одним знаком после запятой
         
        if (TimeDisp[2] > TimeDisp[1] & TimeDisp[1] > TimeDisp[0]){  // Условие вывода обозначения роста давления
            u8g.drawStr(55, 62, "+");                             // Вывод символа роста давления
        } 
         else if (TimeDisp[2] < TimeDisp[1] & TimeDisp[1] < TimeDisp[0]) {      // Условие вывода обозначения падения давления
            u8g.drawStr(55, 62, "-");                             // Вывод символа падения давления
        } 
         else { u8g.drawStr(55, 62, "+-"); }                      // Условие и вывод символа неустойчивой тенденции изменения давления

    }
    while(u8g.nextPage());
}

void Press() {                                                    // Функция формирования массива динамики изменения давления
if (millis() - timing > 2500000){                                 // Условие внесение данных давления в массив по времени
  
   TimeDisp[0] = TimeDisp[1];                                     // Занесение в массив значений со смещением по истечении времени счета
   TimeDisp[1] = TimeDisp[2];
   TimeDisp[2] = sensor.pressure,1;
   timing = millis();                                             // Сброс тайминга для следующего отсчета
  }

if (millis() - timing < 0){                                       // Проверка сброса функции millis() в начальное состояние
   timing = millis();                                             // Сброс тайминга для восстановления функциональности
  }
}
